@@ -16,8 +16,8 @@ assert node2 is not None
 def test_one_fix():
     edit = node1.replace("let b = 456")
     r = node1.range()
-    assert edit.position == r.start.index
-    assert edit.deleted_length == r.end.index - edit.position
+    assert edit.start_pos == r.start.index
+    assert edit.end_pos == r.end.index
     s = node1.commit_edits([edit])
     assert s == "let b = 456"
     s = root.commit_edits([edit])
@@ -28,7 +28,7 @@ def test_multiple_fix():
     root = sg.root()
     nodes = root.find_all(kind="number")
     edits = [node.replace('114514') for node in nodes]
-    edits = sorted(edits, key=lambda x: x.position, reverse=True)
+    edits = sorted(edits, key=lambda x: x.start_pos, reverse=True)
     s = root.commit_edits(edits)
     assert s == "いいよ = log(114514) + log(114514)"
 
@@ -46,7 +46,7 @@ def test_modified_fix():
     node = root.find(kind="number")
     assert node
     edit = node.replace('こいよ')
-    edit.position -= 1
-    edit.deleted_length += 2
+    edit.start_pos -= 1
+    edit.end_pos += 1
     s = root.commit_edits([edit])
     assert s == "いいよ = logこいよ"
\ No newline at end of file
